package Enbld::Definition::Dummy;

use 5.012;
use warnings;

use parent qw/Enbld::Definition/;

1;
